{% extends 'base.html' %} {% block title %} History of {% if path %}{{ path }} - {% endif %} {{ super() }} {% endblock %} {% block content %} {% include 'tree.inc.html' %} {% macro pagination() %}
{% if page %} {% for n in previous_pages %} {% if n is none %} ... {% else %} {{ n }} {% endif %} {% endfor %} {% endif %} {% if more_commits %} »» {% else %} »» {% endif%}
{% endmacro %}

## {% if subpaths %} History of {% for name, subpath in subpaths %} {{ name }} {% if not loop.last %} / {% endif %} {% endfor %} {% else %} Commit History {% endif %} @{{ rev }} {% if USE_SMARTHTTP %} `git clone {{ url_for('history', repo=repo.name, _external=True) }}` {% endif %}

{{ pagination() }}

{% for commit in history %}
- {{ commit.message|force_unicode|shorten_message }} {{ commit.author|force_unicode|extract_author_name }} {{ commit.commit_time|timesince }} ago
{% endfor %}

{{ pagination() }}
{% endblock %}